<?php
// +----------------------------------------------------------------------
// | 消息中心，单条失败记录重发
// +----------------------------------------------------------------------
// | Copyright (c) 2018 https://blog.junphp.com All rights reserved.
// +----------------------------------------------------------------------
// | Licensed ( http://www.apache.org/licenses/LICENSE-2.0 )
// +----------------------------------------------------------------------
// | Author: 小黄牛 <1731223728@qq.com>
// +----------------------------------------------------------------------

namespace app\socket\controller\api\message_center;
use think\Db;

class get_resend {
    // 连接池实例
    private $read_obj;
    private $mysql_obj;

    // 构造函数创建连接池
    public function __construct() {
        $this->read_obj = \pool\MysqlPool::run()->read_pop();
        $this->write_obj = \pool\MysqlPool::run()->write_pop();
    }
    
    // 利用析构函数归回连接，并消耗内存
    public function __destruct() {
        # 归回连接
        \pool\MysqlPool::run()->read_free($this->read_obj);
        # 归还连接
        \pool\MysqlPool::run()->write_free($this->write_obj);
        # 销毁内存
        unset($this->read_obj);
        unset($this->write_obj);
    }

    /**
     * 统一入口
     * @todo 无
     * @author 小黄牛
     * @version v1.0.9 + 2020.04.16
     * @deprecated 暂不启用
     * @global 无
     * @param swoole $ws 实例
     * @param swoole $request 请求体信息
     * @param response $response 请求内容 来源类实例也在里面
     * @return void
    */
    public function run($ws, $request, $response) {
        # 获取请求参数，不区分请求类型，POST优先
        $param = $response->class->param($request);
        # 可以这样判断请求类型
        if ($request->server['request_method'] != 'GET') {
            # 如果需要返回消息，可以这样
            $response->class->endRequest($request, $response, '301', '请求类型错误');
            # 注意，在接口中不能exit，否则会报错的
            return false;
        }
        if (empty($param['id'])) {
            $response->class->endRequest($request, $response, '301', '请输入记录ID');
            return false;
        }

        # 获取mysql连接
        $read_db = $this->read_obj['db'];
        $write_db = $this->write_obj['db'];
        # 获取必备参数
        $table = $ws->config['websocket_redis_message_center_table'];
        
        # 查出
        $sql = \db\SwooleDb::run()->table($table.'_log')->where('id', $param['id'])->find();
        $info = $read_db->query($sql);
        if (empty($info[0])) {
            $response->class->endRequest($request, $response, '301', '数据不存在');
            return false;
        }
        
        $sql = \db\SwooleDb::run()->table($table.'_log')->where('id', $param['id'])->update([
            'create_time' => time(),
            'num' => $info[0]['num']+1,
        ]);
        $write_db->query($sql);

        $res = \app\socket\controller\vendor\Tool::againReturn($ws, $info[0]['fd'], $info[0]['data']);
        if (!$res) {
            $response->class->endRequest($request, $response, '301', '消息重发失败');
            return false;
        }

        $response->class->endRequest($request, $response, '200', '消息重发成功');
        return true;
    }

    /**
     * 该接口文档说明
     * @author 小黄牛
     * @version v1.0.1 + 2020.02.24
    */
    public function _link() {
        return [
            // 请求头
            'header' => [
                'method' => 'GET', // 请求类型
                'code' => 'utf-8', // 内容编码
                'content-type' => 'application/x-www-form-urlencoded', // 数据类型
                // 其余自定义header
            ],
            // 请求参数
            'param' => [
                // 参考格式
                'id' => '1', // 记录ID int(13) 不可为空
            ],
            // 返回值
            'return' => [
                // 状态码囊括
                'code' => [
                    '200' => '请求正常', 
                    '301' => '错误提示', 
                    '500' => '服务器错误',
                ],
                // data部分返回值说明
                'data' => [ //
                ]
            ]
        ];
    }
}
