<?php
// +----------------------------------------------------------------------
// | 工具类
// +----------------------------------------------------------------------
// | Copyright (c) 2018 https://blog.junphp.com All rights reserved.
// +----------------------------------------------------------------------
// | Licensed ( http://www.apache.org/licenses/LICENSE-2.0 )
// +----------------------------------------------------------------------
// | Author: 小黄牛 <1731223728@qq.com>
// +----------------------------------------------------------------------

namespace app\socket\controller\vendor;
use think\facade\Config;

class Tool {

    //获取配置文件
    public static function get_config() {
        return Config::pull('laf');
    }
    
    /** 
     * AES加密方法，对数据进行加密，返回加密后的数据 
     * @param string $data 要加密的数据 
     * @return string 
     */  
    public static function encrypt($data) {  
        $_config = self::get_config();
        return openssl_encrypt($data, $_config['websocket_aes_type'], $_config['websocket_aes_key'], 0, $_config['websocket_aes_iv']);  
    }  
  
    /** 
     * AES解密方法，对数据进行解密，返回解密后的数据 
     * @param string $data 要解密的数据 
     * @return string 
     */  
    public static function decrypt($data) {  
        $_config = self::get_config();
        return openssl_decrypt($data, $_config['websocket_aes_type'], $_config['websocket_aes_key'], 0, $_config['websocket_aes_iv']);  
    } 

    /**
     * 获取参数
     * @todo 无
     * @author 小黄牛
     * @version v1.0.1 + 2020.1.13
     * @deprecated 暂不启用
     * @global 无
     * @param void $data
     * @param array $_config 配置项
     * @return void
    */
    public static function get_data($data, $_config) {
        // 启用加密方式
        if ($_config['websocket_aes_key']) {
            $data = self::decrypt($data);
        }
        return json_decode($data, true);
    }

    /**
     * 发送数据包
     * @todo 无
     * @author 小黄牛
     * @version v1.0.13 + 2020.05.04
     * @deprecated 暂不启用
     * @global 无
     * @param Swoole $ws 实例
     * @param string $fd 推送标记
     * @param string $msg 说明
     * @param mixed $data 结果集
     * @return void
    */
    public static function ajaxReturn($ws, $fd, $msg='success', $data=[]) {
        $row = current(debug_backtrace());
        $action = basename($row['file'],".php");
        $_config = self::get_config();
        $array = [
            'action' => $action,
            'msg' => $msg,
            'data' => $data
        ];
        $content = json_encode($array, JSON_UNESCAPED_UNICODE);

        // 启用加密方式
        if ($_config['websocket_aes_key']) {
            $content = self::encrypt($content);
        }

        # 获取redis连接
        $redis_obj = \pool\RedisPool::run()->pop();
        $redis = $redis_obj['redis'];
        // 消息中心数据
        try {
            $ret = $ws->push($fd, $content);
            // 推送成功就更新统计数
            $key = $ws->message_center_success.date('Ymd', time());
            $redis->incr($key);
            # 归还连接
            \pool\RedisPool::run()->free($redis_obj);
            return $ret;
        } catch (\Exception $e) {
            // 推送失败就更新统计数
            $key = $ws->message_center_error.date('Ymd', time());
            $redis->incr($key);
            # 归还连接
            \pool\RedisPool::run()->free($redis_obj);
            // 然后写入消息中心
            $obj = \pool\MysqlPool::run()->write_pop();
            if (!empty($obj['db'])) {
                # 使用构造器，构造出SQL语句
                $sql = \db\SwooleDb::run()->table($ws->config['websocket_redis_message_center_table'].'_work')->insert([
                    'action' => $action,
                    'fd' => $fd,
                    'data' => $content,
                    'create_time' => time(),
                    'num' => 0,
                ]);
                $db = $obj['db'];
                # 执行查询操作
                $ret = $db->query($sql);
                // 用完之后归回给连接池 - 用read_free归回select业务连接
                \pool\MysqlPool::run()->write_free($obj);
            }

            return false;
        }
    } 

    /**
     * 用于消息队列重发数据包
     * @todo 无
     * @author 小黄牛
     * @version v1.0.13 + 2020.05.04
     * @deprecated 暂不启用
     * @global 无
     * @param Swoole $ws 实例
     * @param string $fd 推送标记
     * @param mixed $content 结果集
     * @return void
    */
    public static function againReturn($ws, $fd, $content) {
        $_config = self::get_config();
        
        try {
            $ret = $ws->push($fd, $content);
            return $ret;
        } catch (\Exception $e) {
            return false;
        }
    } 
}
